summaryrefslogtreecommitdiffstats
path: root/cc/animation_curve.h
diff options
context:
space:
mode:
authorenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
committerenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
commitc753e25a8b4366c44134a8c21b9ed3392bf48608 (patch)
treef378c8a762caccf60856a1670ae33dfd638b9453 /cc/animation_curve.h
parent503160f80568f024fa712e280bb1a4e1e6ca1ec3 (diff)
downloadchromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.zip
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.gz
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.bz2
Revert "cc: Rename cc classes and members to match filenames"
This reverts commit 184fac5add06d5f4670fa6be4a4d3b39232d51bb. git-svn-id: svn://svn.chromium.org/chrome/trunk/src@163059 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'cc/animation_curve.h')
-rw-r--r--cc/animation_curve.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/cc/animation_curve.h b/cc/animation_curve.h
index 50dde07..7ed6e7a 100644
--- a/cc/animation_curve.h
+++ b/cc/animation_curve.h
@@ -10,44 +10,44 @@
namespace cc {
-class FloatAnimationCurve;
-class TransformAnimationCurve;
+class CCFloatAnimationCurve;
+class CCTransformAnimationCurve;
class IntSize;
class TransformOperations;
// An animation curve is a function that returns a value given a time.
// There are currently only two types of curve, float and transform.
-class AnimationCurve {
+class CCAnimationCurve {
public:
enum Type { Float, Transform };
- virtual ~AnimationCurve() { }
+ virtual ~CCAnimationCurve() { }
virtual double duration() const = 0;
virtual Type type() const = 0;
- virtual scoped_ptr<AnimationCurve> clone() const = 0;
+ virtual scoped_ptr<CCAnimationCurve> clone() const = 0;
- const FloatAnimationCurve* toFloatAnimationCurve() const;
- const TransformAnimationCurve* toTransformAnimationCurve() const;
+ const CCFloatAnimationCurve* toFloatAnimationCurve() const;
+ const CCTransformAnimationCurve* toTransformAnimationCurve() const;
};
-class FloatAnimationCurve : public AnimationCurve {
+class CCFloatAnimationCurve : public CCAnimationCurve {
public:
- virtual ~FloatAnimationCurve() { }
+ virtual ~CCFloatAnimationCurve() { }
virtual float getValue(double t) const = 0;
// Partial Animation implementation.
virtual Type type() const OVERRIDE;
};
-class TransformAnimationCurve : public AnimationCurve {
+class CCTransformAnimationCurve : public CCAnimationCurve {
public:
- virtual ~TransformAnimationCurve() { }
+ virtual ~CCTransformAnimationCurve() { }
virtual WebKit::WebTransformationMatrix getValue(double t) const = 0;
// Partial Animation implementation.
virtual Type type() const OVERRIDE;
};
@@ -10,44 +10,44 @@
virtual float getValue(double t) const = 0;
- // Partial Animation implementation.
+ // Partial CCAnimation implementation.
virtual Type type() const OVERRIDE;
};
@@ -10,44 +10,44 @@
virtual WebKit::WebTransformationMatrix getValue(double t) const = 0;
- // Partial Animation implementation.
+ // Partial CCAnimation implementation.
virtual Type type() const OVERRIDE;
};